@@ -39,6 +39,8 @@ from Products.statusmessages.interfaces import IStatusMessage
 
 try:
     from Products.PloneGetPaid.interfaces import IBuyableMarker
+    from Products.PloneGetPaid.interfaces import PayableMarkerMap
+    from Products.PloneGetPaid.interfaces import IPayableMarker
     GETPAID_EXISTS = True
 except ImportError:
     GETPAID_EXISTS = False
@@ -94,6 +96,33 @@ class CommonBrowserView(BrowserView):
         else:
             return True
         
+    def addPaypalButton(self, label, name, price):
+        return """
+            <form action="https://www.paypal.com/cgi-bin/webscr" method="post">
+                <input name="business" type="hidden" value="arnolfini@intk.com" />
+                <input name="amount" type="hidden" value="%(price).2f" />
+                <input name="item_name" type="hidden" value="%(name)s" />
+                <input name="no-shipping" type="hidden" value="1" />
+                <input name="currency_code" type="hidden" value="GBP" />
+                <input name="cpp_header_image" type="hidden" value="http://new.arnolfini.org.uk/++resource++plonetheme.arnolfini.images/arnolfiniLogo.png" />
+                <input name="return" type="hidden" value="http://new.arnolfini.org.uk/about/support/thank-you/" />
+                <input name="cmd" type="hidden" value="_xclick" />
+                <input type="submit" value="%(label)s" />
+            </form>
+        """%{"price": price, "name": name, "label": label}
+    
+    def payable(self, item):
+        """Return the payable (shippable) version of the context.
+        """
+        if GETPAID_EXISTS:
+            iface = PayableMarkerMap.get(IBuyableMarker, None)
+            if iface is None:
+                print("Something is badly wrong here.")
+                return None
+            return iface( item )
+        else:
+            return none
+        
     def checkPermission(self, item, permission):
         secman = getSecurityManager()
         return secman.checkPermission(permission, item)
